<?php
/**
 * Triggers
 *
 * @package GamiPress\LifterLMS\Triggers
 * @since 1.0.0
 */

// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

/**
 * Register LifterLMS specific triggers
 *
 * @param array $triggers
 * @return mixed
 */
function gamipress_lifterlms_activity_triggers( $triggers ) {

    $triggers[__( 'LifterLMS', 'gamipress-lifterlms-integration' )] = array(

        'gamipress_lifterlms_complete_lesson' => __( 'Complete a lesson', 'gamipress-lifterlms-integration' ),
        'gamipress_lifterlms_complete_specific_lesson' => __( 'Complete a specific lesson', 'gamipress-lifterlms-integration' ),

        'gamipress_lifterlms_complete_section' => __( 'Complete a section', 'gamipress-lifterlms-integration' ),
        'gamipress_lifterlms_complete_specific_section' => __( 'Complete a specific section', 'gamipress-lifterlms-integration' ),

        'gamipress_lifterlms_complete_course' => __( 'Complete a course', 'gamipress-lifterlms-integration' ),
        'gamipress_lifterlms_complete_specific_course' => __( 'Complete a specific course', 'gamipress-lifterlms-integration' ),
    );

    return $triggers;

}
add_filter( 'gamipress_activity_triggers', 'gamipress_lifterlms_activity_triggers' );

/**
 * Register LifterLMS specific activity triggers
 *
 * @since  1.0.0
 *
 * @param  array $specific_activity_triggers
 * @return array
 */
function gamipress_lifterlms_specific_activity_triggers( $specific_activity_triggers ) {

    $specific_activity_triggers['gamipress_lifterlms_complete_specific_lesson'] = array( 'lesson' );
    $specific_activity_triggers['gamipress_lifterlms_complete_specific_section'] = array( 'section' );
    $specific_activity_triggers['gamipress_lifterlms_complete_specific_course'] = array( 'course' );

    return $specific_activity_triggers;
}
add_filter( 'gamipress_specific_activity_triggers', 'gamipress_lifterlms_specific_activity_triggers' );

/**
 * Register LifterLMS specific activity triggers labels
 *
 * @since  1.0.0
 *
 * @param  array $specific_activity_trigger_labels
 * @return array
 */
function gamipress_lifterlms_specific_activity_trigger_label( $specific_activity_trigger_labels ) {

    $specific_activity_trigger_labels['gamipress_lifterlms_complete_specific_lesson'] = __( 'Complete the lesson %s', 'gamipress-lifterlms-integration' );
    $specific_activity_trigger_labels['gamipress_lifterlms_complete_specific_section'] = __( 'Complete the section %s', 'gamipress-lifterlms-integration' );
    $specific_activity_trigger_labels['gamipress_lifterlms_complete_specific_course'] = __( 'Complete the course %s', 'gamipress-lifterlms-integration' );

    return $specific_activity_trigger_labels;
}
add_filter( 'gamipress_specific_activity_trigger_label', 'gamipress_lifterlms_specific_activity_trigger_label' );

/**
 * Get user for a given trigger action.
 *
 * @since  1.0.0
 *
 * @param  integer $user_id user ID to override.
 * @param  string  $trigger Trigger name.
 * @param  array   $args    Passed trigger args.
 * @return integer          User ID.
 */
function gamipress_lifterlms_trigger_get_user_id( $user_id, $trigger, $args ) {

    switch ( $trigger ) {
        case 'gamipress_lifterlms_complete_lesson':
        case 'gamipress_lifterlms_complete_specific_lesson':

        case 'gamipress_lifterlms_complete_section':
        case 'gamipress_lifterlms_complete_specific_section':

        case 'gamipress_lifterlms_complete_course':
        case 'gamipress_lifterlms_complete_specific_course':
            $user_id = $args[1];
            break;
    }

    return $user_id;

}
add_filter( 'gamipress_trigger_get_user_id', 'gamipress_lifterlms_trigger_get_user_id', 10, 3 );

/**
 * Get the id for a given specific trigger action.
 *
 * @since  1.0.0
 *
 * @param  integer  $specific_id Specific ID.
 * @param  string  $trigger Trigger name.
 * @param  array   $args    Passed trigger args.
 *
 * @return integer          Specific ID.
 */
function gamipress_lifterlms_specific_trigger_get_id( $specific_id, $trigger = '', $args = array() ) {

    switch ( $trigger ) {
        case 'gamipress_lifterlms_complete_specific_lesson':

        case 'gamipress_lifterlms_complete_specific_section':

        case 'gamipress_lifterlms_complete_specific_course':
            $specific_id = $args[0];
            break;
    }

    return $specific_id;
}
add_filter( 'gamipress_specific_trigger_get_id', 'gamipress_lifterlms_specific_trigger_get_id', 10, 3 );

/**
 * Extended meta data for event trigger logging
 *
 * @since 1.0.0
 *
 * @param array 	$log_meta
 * @param integer 	$user_id
 * @param string 	$trigger
 * @param integer 	$site_id
 * @param array 	$args
 *
 * @return array
 */
function gamipress_lifterlms_log_event_trigger_meta_data( $log_meta, $user_id, $trigger, $site_id, $args ) {

    switch ( $trigger ) {
        case 'gamipress_lifterlms_complete_lesson':
        case 'gamipress_lifterlms_complete_specific_lesson':
            // Add the lesson ID
            $log_meta['lesson_id'] = $args[0];
            break;
        case 'gamipress_lifterlms_complete_section':
        case 'gamipress_lifterlms_complete_specific_section':
            // Add the section ID
            $log_meta['section_id'] = $args[0];
            break;
        case 'gamipress_lifterlms_complete_course':
        case 'gamipress_lifterlms_complete_specific_course':
            // Add the course ID
            $log_meta['course_id'] = $args[0];
            break;
    }

    return $log_meta;
}
add_filter( 'gamipress_log_event_trigger_meta_data', 'gamipress_lifterlms_log_event_trigger_meta_data', 10, 5 );